@@ -5,13 +5,13 @@ class Borda(WeaklySeparable):
     """Borda vote scoring rule"""
 
     def find_committee(self, k, profile):
-        if self.weights is None or len(self.weights) != k:
+        if self.weights is None or len(self.weights) != len(profile.candidates):
             self.weights = self._borda_weights(len(profile.candidates))
         committee = WeaklySeparable.find_committee(self, k, profile)
         return committee
 
     def compute_score(self, candidate, k, profile):
-        if self.weights is None or len(self.weights) != k:
+        if self.weights is None or len(self.weights) != len(profile.candidates):
             self.weights = self._borda_weights(len(profile.candidates))
         score = WeaklySeparable.compute_score(self, candidate, k, profile)
         return score
